# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Net-FTPSSL
Version:	0.42
Release:	2.%{__distinit}%{__distvers}
Summary:	Perl module for FTP over SSL/TLS
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Net-FTPSSL
Source0:	https://cpan.metacpan.org/modules/by-module/Net/Net-FTPSSL-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(IO::Socket::INET)
BuildRequires:	perl(IO::Socket::SSL) >= 1.86
BuildRequires:	perl(Net::HTTPTunnel)
BuildRequires:	perl(Net::SSLeay::Handle)
BuildRequires:	perl(strict)
BuildRequires:	perl(Sys::Hostname)
BuildRequires:	perl(Time::Local)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::HomeDir)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::More)
# Runtime
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Net::HTTPTunnel)

%description
Net::FTPSSL is a class implementing a simple FTP client over a Secure
Sockets Layer (SSL) or Transport Layer Security (TLS) connection written in
Perl as described in RFC959 and RFC2228. It will use TLS by default.

%prep
%setup -q -n Net-FTPSSL-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
PERL_MM_USE_DEFAULT=1 make test

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Net/
%{_mandir}/man3/Net::FTPSSL.3*

%changelog
* Wed Mar 29 2023 Paul Howarth <paul@city-fan.org> - 0.42-2
- Use SPDX-format license tag
- Use %%license unconditionally

* Thu Oct  3 2019 Paul Howarth <paul@city-fan.org> - 0.42-1
- Update to 0.42
  - Changed the copyright from 2018 to 2019 in all files
  - Removed search.cpan.org link from the POD since that link seems to be in
    the process of being deprecated on CPAN after its redesign in 2018
  - Added BUILD_REQUIRES option to Makefile.PL
  - New aliases "ls" and "dir" to nlst and list respectively (CPAN RT#130578)

* Fri Dec 21 2018 Paul Howarth <paul@city-fan.org> - 0.41-1
- Update to 0.41
  - Fixed supported() to say HELP isn't supported if OverrideHELP was used
  - Fixed nlst/list bug when filter patterns and callbacks were both in use
  - Fixed nlst/list to both call _common_list() instead of having list do both
  - The DebugLogFile option now turns autoflush on when the log file is opened
  - Tweaked the ccc() hack slightly
  - Added uput2() method to deal with the problem that uput() can't always tell
    you the actual name of the file on the FTPS server and you really need to
    know that filename (slow)
  - Rewrote the uput() POD to reflect what the command actually does instead
    of what it's supposed to do; different servers implemented it differently
  - Tweaked the deprecated "useSSL" option to make it easier to remove in the
    future
  - Minor tweaks to _help() and supported() dealing with OverrideHELP and
    _help() can now include disabled commands in its hash (the key's value is 0
    if disabled, Else non-zero if a supported command)
  - Added mlsd() - List of files in machine readable format
  - Added mlst() - Get file details in machine readable format
  - Added parse_mlsx() to parse the returned values of mlsd() and mlst()
  - Modified size() to have option of using MLST as an alternate way to get a
    file's size
  - Modified is_dir() and is_file() to be able to use MLST as the preferred way
    to do these tests; falls back on original tests if MLST isn't supported or
    doesn't have the TYPE feature enabled
  - Redesigned all the test cases from scratch! Rather than choose one of 3
    huge scripts to run, everything has been replaced by a lot of smaller test
    cases, which makes it much simpler to verify everything is working without
    the need for messy, complex code or having to carefully examine log files
    afterwards
  - The test cases no longer uses the deprecated "useSSL" option; they use the
    "SSL_version" option instead
  - t/test-helper/helper1234.pm, new helper module to centralize the asking of
    questions and to share the answers between all the test cases (so that
    "make test" only prompts you a single time for your server info)
  - No longer uses environment variables to "remember" answers
  - MANIFEST - Added all the new test cases and removed the old ones
  - Updated the LICENSE file to say 2018 (from 2017)
  - Update the README file to say 2018 (from 2017), then completely rewrote it
- Switched upstream from search.cpan.org to metacpan.org

* Wed Mar  7 2018 Paul Howarth <paul@city-fan.org> - 0.40-1
- Update to 0.40
  - Updated the copyright to 2018
  - Updated README to reference the new FTPSSL_SSL_VER environment variable for
    the test case prompts (t/*.t); also fixed several typos in this file
  - Updated "_mdtm()" to allow for dates from 1999 and earlier (CPAN RT#124570)

* Wed Oct 25 2017 Paul Howarth <paul@city-fan.org> - 0.39-1
- Update to 0.39
  - Updated the LICENSE file to 2017 (from 2015)
  - Changed default from TLS v1.0 to TLS v1.2 and rearranged the POD a bit
  - Started deprecating useSSL; now warns to use option "SSL_version" instead

* Mon Apr  3 2017 Paul Howarth <paul@city-fan.org> - 0.38-1
- Update to 0.38
  - PreserveTimestamp bugs with _mfmt() and _mdtm(); I pulled the arguments off
    the stack in the wrong order (CPAN RT#120802)
  - Added instructions on how to install this module in an alternate location
    to the README file
- Drop support for EOL distributions prior to F-13:
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Mon Mar 27 2017 Paul Howarth <paul@city-fan.org> - 0.37-1
- Update to 0.37
  - Found an issue with size() function when it gets the file size via "STAT";
    found a server where "STAT" returned the results in a different format
  - Removed duplicate setting of {help_cmds_no_syntax_available} key in _help()
  - When Croak=>1 is turned on, don't treat failure of "SITE HELP" as a fatal
    error
    (CPAN RT#120623)


* Thu Mar 23 2017 Paul Howarth <paul@city-fan.org> - 0.36-1
- Update to 0.36
  - Added additional module versions to the logs in BEGIN
  - CPAN RT#120341: The latest release of IO-Socket-SSL broke this module
    (v2.046 broken, v2.012 worked); looks like the start_SSL() call is
    removing my "_FTPSSL_arguments" hash entry
  - CPAN RT#120623: The OverrideHELP option had issues: shouldn't have called
    _feat() or _site_help() for =>1 or =>\@lst, so removed in _help()
  - CPAN RT#120621: Request for a new feature of allowing objects that inherit
    from IO::Handle wherever it asks for a GLOB! put/get/DebugLogFile/etc.
  - Implemented via new helper function _isa_glob(); also updated POD
  - Updated README section on using client certificates
  - Updated t/20-certificate.t to use a callback and updated the %%certificate
    hash

* Tue Nov  8 2016 Paul Howarth <paul@city-fan.org> - 0.35-1
- Update to 0.35
  - Minor POD updates
  - Added catastrophic failure protection to _croak_or_return() by adding
    local $SIG{PIPE} = "IGNORE"; before connection termination logic
    (CPAN RT#118418)

* Fri Jul 29 2016 Paul Howarth <paul@city-fan.org> - 0.34-1
- Update to 0.34
  - Behaviour change: Added fix_supported() as a way to make corrections to
    supported(); editing the returned hash reference of _help() no longer
    works - this new method does both additions and removals
  - Behaviour change: Modified _mfmt() and _mdtm() to be able to handle
    localtime vs. gmtime based on changes to how PreserveTimestamp work; as an
    alternate way, the behaviour can be overridden by a new $local_flag option
    (the default behaviour is still GMT)
  - Made POD clarification and other comment updates
  - Increased TRACE_MOD from 5 to 10 blocks
  - Added BEGIN block to detect if IPv6 support is possible; it does this by
    asking IO::Socket::SSL instead of reinventing the wheel
  - Moved the generation of the Debug log header info for CPAN support to BEGIN
    as well so that this info gets centralized instead of repeated
  - Added Domain/Family as a new option for choosing IPv4 vs. IPv6
  - Added OverrideHELP => -1 option to use FEAT instead, when HELP is broken
  - Updated quot() to recognize that MLSD also requires a data channel
    Also improved the disable HELP logic used here
  - Broke up _feat() into _feat() and feat(), and added feat() to the POD;
    this was done since under some circumstances the feature list can be
    dynamic
  - Rewrote _help() to make it less confusing
  - Fixed PreserveTimestamp bug in transfer() and xtransfer()
  - Added new option xWait for use by xput() and xtransfer(); some servers
    won't honour the rename of the scratch file to its final name without
    instituting a delay, so this option allows you to specify one
  - README: Added more notes about turning on/off SSL logging; newer versions
    allow for dynamic turning on/off
  - t/10-complex.t: Changes to the main test script:
    - Now uses fix_supported() in its is_file() tests since these test cases
      hit some lies told by some servers
    - Fixed so its main logs are named after this test program like the other
      test cases do
    - Added new test to verify if the MDTM command correctly uses GMT time
      instead of local time (assumes MFMT will use the same time zone)
    - Added xWait of 1 second to deal with problem FTP/S servers that require
      a wait for the xput and xtransfer tests to work
  - t/05-readonly.t: Renamed 05-simple to 05-readonly to more accurately
    describe the types of tests this test script does

* Fri Jul  8 2016 Paul Howarth <paul@city-fan.org> - 0.33-1
- Update to 0.33
  - Behaviour change: Since many openssl libraries are tightening their
    security, I'm adding a new option to preserve backwards compatibility:
    - By default this module now reuses the context of the command channel
      when opening a data channel
    - If you need to revert back to the previous default of not reusing the
      context for data channels, you must now use option "DisableContext => 1"
      to do so; hopefully the need for this option will be rare
    - See the POD for more details
  - Behaviour change: Added support for SNI in the SSL handshake
  - Changed logic on how to detect if a default "SSL_verify_mode" value needed
    to be set to VERIFY_NONE() for the caller in new()
  - Can now pass SSL options directly to new():
    - You no longer need to use the "SSL_Client_Certificate" option to pass the
      hash reference of SSL options
    - Currently only recognises IO::Socket::SSL options that start with SSL_
    - If any start with something else, they will be addressed in a future
      release
  - Clarified some POD information on a few methods
  - Enhanced "size" function to use STAT if SIZE isn't available
  - Fixed case where sometimes the login account used wasn't being masked in
    the response in the logs
  - Now print the INET version in the log file
  - Reset $ERRSTR in new() in case previous call had errors
  - Fixed t/10-complex.t func run_stat_test() to test the "is_file" and
    "is_dir functions; some tests disable the "SIZE" command so it can test
    the new alternate size logic as well
  - New test program t/05-simple.t that does a simple read only test against
    the FTPS server
    - Added so that you can run a simple test against servers you don't want to
      upload anything to during the tests
    - These tests are not as robust as the t/10-complex.t tests so failures
      here are not as meaningful; hence, run t/10-complex if you encounter any
      issues for more analysis
  - Added t/05-simple.t to the MANIFEST
  - Updated the Copyright in the README file, and reworded a few sections
  - Updated all t/*.t files to add a retry the 1st time they try to connect
    to a server via new(); added a hard coded "SSL_cipher_list" value if the
    defaults don't work (this kludge might not work for everyone)
  - Modified t/20-certificate.t to be a bit more robust
  - NOTE: Found a server where supported() doesn't completely work; that server
    fails to put a "*" after some of the commands it didn't implement

* Wed Jun 15 2016 Paul Howarth <paul@city-fan.org> - 0.32-1
- Update to 0.32
  - Clarified some POD information on a few methods
  - Changed the use_ssl test when providing custom SSL_Version settings via the
    SSL_Client_Certificate option: now does a positive test for SSL instead of
    a negative test (CPAN RT#115296)
  - Modified t/10-complex.t to do a better uput test, and put into its own test
    function so that the filename returned could be validated instead of just
    assuming it was correct
  - Added additional test cases for files with spaces in their names
  - Added run_stat_test() for future tests for "is_..." functions
- BR: perl-generators where available

* Mon Apr 18 2016 Paul Howarth <paul@city-fan.org> - 0.31-1
- Update to 0.31
  - Updated the Copyright
  - Fixed issue where "uput" cmd generated "Invalid number of parameters" error
  - Implemented mdtm() server bug fix: some rare servers do (19xx) instead of
    (20xx) for the year part of the timestamp returned, so implemented
    autodetection and fix for this server issue
  - Added undocumented Debug value to suppress printing out the HELP
    information during login, which got in the way of debugging via ad-hoc perl
    scripts
  - Added is_file() to validate if the given name is a regular file
  - Added is_dir() to validate if the given name is a directory
  - Fixed bug in t/10-complex.t that made it look like "make test" succeeded
    when in fact it encountered a fatal error forcing it to skip over all the
    other deeper tests
  - Fixed some undef warnings in "uput() test" in t/10-complex.t when talking
    to buggy windows FTPS servers that says it supports "uput" but handles it
    really strangely or not at all; now also handles new "?" return value in
    the strange case
  - Fixed bug in t/10-complex.t in test_log_redirection() failing a EPSV test
    when the destination server didn't support this functionality
  - Modified t/10-complex.t to print the "OK" results to the log file, which
    makes it a bit easier to associate failures to what's in the log file
  - Fixed some typos in the POD
- Simplify find command using -delete

* Fri Aug 14 2015 Paul Howarth <paul@city-fan.org> - 0.30-1
- Update to 0.30
  - INCOMPATIBILITY WARNING! If you've been hacking internal undocumented
    variables referenced by my module, your code is most likely broken with
    this release! If you've been doing
    "$ftps = new (...); $x = ${*$ftps}{abc};", it's now
    "$x = ${*$ftps}{_FTPSSL_arguments}->{abc};" for a lot of them; this
    change was made to make it less likely I'll accidentally step on an
    IO::Socket::SSL variable in a future release of either module
  - Changed t/00-basic.t so it no longer needs to call uc(); also now uses
    __PACKAGE__ keyword instead of hard coded text
  - Fixed error message bug in _get_data_channel(); got SSL_version from wrong
    hash
  - Reorganized the order of some functions in the POD
  - Fixed minor bug in the masking of the user id when writing to a log file
  - Looks like the sysread() in response() is sometimes spuriously setting the
    special variable "$!" on Perl 5.10.1 for AIX 7.1; so, if the command looks
    complete, I'm going to ignore the error message in "$!", at least for now
  - EXPERIMENTAL: Added 2 new functions: set_dc_from_hash() and
    copy_cc_to_dc(), which provide two different ways to micro-manage the SSL
    options used to manage the Data Channel without the need to hack the code
    base

* Tue Jul  7 2015 Paul Howarth <paul@city-fan.org> - 0.29-1
- Update to 0.29
  - Updated README file with info on how to turn on SSL tracing so that I can
    more easily find that information again
  - Fixed log display issue if there was no username and/or password passed
    to login()
  - In quot(), fixed pattern match bug when setting $cmd2 (\S* to \S+)
  - Added LICENSE tag to Makefile.PL
  - Added LICENSE file to my package
  - Rewrote Makefile.PL to support optional parameters
  - Added MIN_PERL_VERSION tag to Makefile.PL; enforced version 5.6.1, since
    that is the earliest perl my module was tested against by the smoke
    testers, though it was last tested that way with v0.11 (version 5.8.8 is
    the oldest version of Perl I test against regularly)
  - Added Net::SSLeay as a fake dependency to Makefile.PL and as a test case in
    t/00-basic.t for the benefit of some smoke testers who fail my module due
    to this indirect dependency not working
  - Fixed _print_LOG() to support multiple arguments, so we no longer have to
    concatenate everything before using it
  - Rewrote _debug_print_hash() to be able to handle hashes of any depth; it's
    now recursive with infinite loop detection
  - Added logic to support re-using the session instead of just the context,
    via the new option "ReuseSession=>1" (CPAN RT#76108, CPAN RT#105507)
  - Fixed uc() warning in t/00-basic.t for Perl ≥ 5.12

* Sat Jun 27 2015 Paul Howarth <paul@city-fan.org> - 0.27-3
- Perl 5.22 rebuild

* Mon Mar 30 2015 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27
  - Fixed CPAN RT#102680: Bad "supported" test in xput/xtransfer with regard
    to OverrideHELP=>1 (all other OverrideHELP options worked fine)
  - Added all_supported() to assist in fixing the above bug
  - Some minor POD corrections
  - Added check to quot("HELP") to see if HELP was overridden; required a minor
    change in new() to support this logic
  - Added the INTERPRETING THE LOGS section in the POD text

* Wed Feb 11 2015 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26
  - The deprecated SSL_Advanced option now causes new() to call croak; all
    remaining references to it will be removed in v0.27 or v0.28
  - The POD text no longer mentions the SSL_Advanced option at all
  - Added to README the new environment variable created for the test scripts
    in the previous release
  - The RFC links in the SEE ALSO section had all expired
  - Enhanced _debug_print_hash() to work with regular hashes as well as just
    GLOBs, and also fixed to follow SCALAR references
  - Now dumps to the log file the contents of the SSL_Client_Certificate
    hash if provided; it was difficult to debug logic when it wasn't logged
  - Fixed CPAN RT#101388, reusing SSL_Client_Certificate options on the data
    channel; added additional options to go with SSL_reuse_ctx to resolve this
    issue

* Fri Sep 12 2014 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
  WARNING: this is a major upgrade and may not be 100%% backwards compatible
  with existing code; also, the response() redesign may not work for all FTPS
  servers (it's a work in progress, so comments are welcome)!
  - Upgraded the minimum version of IO-Socket-SSL required from v1.08 to v1.26
    so that I could remove the warnings in the POD for ccc()
  - Modified the Synopsis to use Croak since no one was reading my comments
    about using it too closely anyway
  - Added a new pattern for uput() to check for file names with; also fixed to
    guarantee it will never return any path info, just the base file name
    itself (this change may break existing programs)
  - Another hack to recover from a garbled CCC response, to prevent unnecessary
    warnings
  - Hit a weird FTP server that requires me to flip flop the binary/ASCII
    settings on the server/client (see mixedModeAI() and mixedModeIA())
  - Added a way to print Perl warnings to the log file (trapWarn); it will
    chain things if warnings were already trapped (even between multiple open
    Net::FTPSSL object logs)
  - Added get_log_filehandle() to allow someone to gain access to the open
    filehandle used to write to the log file generated when Debug is turned on
    and you specified a log file via DebugLogFile
  - Now allows DebugLogFile to be an open file handle (GLOB)
  - Fixed quot() to echo the command if it's one of those disallowed; also now
    strips off any leading spaces from the command before using it
  - Use "sub DESTROY" rather than "sub END" for objects (just a FYI); surprise,
    surprise - sometimes END is called before DESTROY is
  - Moved some logic out of quit() into the new DESTROY() method; no longer
    need to hack object termination logic via quit()
  - Added END to handle final clean up for trapWarn()
  - Fixed warnings in function _feat() caused by strange server returns
  - Fixed warnings in function _help() caused by strange server returns
  - Fixed 20-certificate.t bug where $ENV{HOME} is not defined for all OS
  - Fixed 10-complex.t to use the new warning logic
  - Fixed 20-certificate.t to use the new warning logic
  - Fixed t/10-complex.t & t/20-certificate.t to use a 30-second Timeout
    instead of using the default 2 minutes
  - Reworked response() with regard to CPAN RT#97608 (related to
    CPAN RT#73115); had to redesign how this method worked - it was getting too
    convoluted to patch any further and this was the only way to properly fix
    _help and _feat
  - Second issue for CPAN RT#97608 was an issue with very long login messsages
    that hit an unexpected Timeout issue (last release enhancement); turns out
    the Timeout logic in response() didn't always work properly if you didn't
    read in the entire response via a single call to sysread()
  - This rewrite of response() broke the ccc() hack, so had to redesign how
    this hack worked as well (may break existing programs using CCC)
  - Added special case Debug=>99 for more detailed logging for debugging the
    new response code base in the future
  - Added new environment variable (FTPSSL_DEBUG_LEVEL) to t/10-complex.t to
    enable low level debugging of the new response() code
  - Updated the SSL_Advanced deprecated warning that it will soon be removed
    in a future release
- Classify buildreqs by usage

* Tue Jul  1 2014 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24
  - Makefile.PL fix: only asks question if Net::HTTPTunel isn't present; also
    now defaults to "N" instead of "Y" if module not present
  - Fixed bug in supported(); unsupported commands are followed with "*"
    in help - most do "CMD*", but found some servers doing "CMD *" instead
  - Fixed bug in 20-certificate.t where we were getting a false failure
    on nlst(); fixed to explicitly check the response code instead of
    assuming an error when nothing was found (fixed list() as well)
  - Same fix in 10-complex.t, even though tests designed to always return
    something
  - Added transfer() to transfer files from one system to another system
    without the need to make a local copy of the file
  - Added xtransfer() as well
  - Added transfer and xtransfer validation to 10-complex.t to test things out
  - Added a new environment variable default for *.t prompts
  - Fix hang issue when the command channel unexpectedly drops, by implementing
    a timeout in response() (CPAN RT#95411)
- Drop %%defattr, redundant since rpm 4.4

* Tue Aug  6 2013 Paul Howarth <paul@city-fan.org> - 0.23-1
- Update to 0.23
  - Added clarification to use of SSL_Client_Certificate option in pod text
  - Added support for tunneling through a proxy server via the ProxyArgs option
    (CPAN RT#82094)
  - Added optional proxy server questions if Net::HTTPTunnel is installed for
    the test scripts (t/*.t)
  - Fixed bug in login() so the call to help() only happens if the login is
    successful
  - Avoid IO-Socket-SSL versions 1.79 to 1.85 due to bug when using
    certificates for the Data Channel and getting a bogus Man-In-The-Middle
    (MITM) warning (CPAN RT#84376)
  - Avoid MITM warning when not using certificates (CPAN RT#85420)
  - Fixed masking issue when writing to the log file when the value that needed
    to be masked contained regex special chars
  - Added clarification that any warnings printed below the 10-complex.t tests
    are just that: warnings, not errors preventing things from working; they
    are collected so the developer can be notified about them for fixing in
    future releases
- BR:/R: perl(Net::HTTPTunnel)
- Bump perl(IO::Socket::SSL) version requirement to 1.86

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 0.22-2
- Perl 5.16 rebuild

* Sat May 26 2012 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22
  - CPAN RT#77072 requested to autodetect the need for using the PRET command;
    the docs in the POD now mark the Pret option as optional for cases where
    auto-detect doesn't work
  - Fixed issue with ccc that the server sometimes responds to a successful NOOP
    twice, resulting in command/resonses getting out of sync
  - Fixed quot() bug introduced with uc() fix for CPAN RT#74025 in 0.21
  - Fixed the return code in restart() to always be 1 instead of undef, since
    it never fails
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Feb 21 2012 Paul Howarth <paul@city-fan.org> - 0.21-1
- Update to 0.21
  - Fixed bad call to _croak_or_return () in _get_data_channel() when dealing
    with failed certificates for data connections
  - New option to execute PRET (for distributed FTP data channel transfers)
    before all PASV calls (CPAN RT#74547)
  - Updated t/10-complex.t to dynamically check if PRET is needed
  - Added checks to avoid warnings with uc(undef) (CPAN RT#74035)
  - Fixed both test cases to no longer send Port as undefined to get rid of
    warnings in log file (passing undef wasn't realistic, was just convenient)
  - t/10-complex.t now explicitly checks if any warnings are generated and does
    a request for feadback instead of as an error if any are found, which
    should help considerably with debugging any code changes in the future
  - Added new internal method _feat() to get additional commands to be
    recognized by supported()
  - Enhanced _help() in parsing its response from the server and other
    significant enhancements (major rewrite of this one method)
  - Above rewrite uncovered bug in t/10-complex.t to fix in a supported() test
  - Did some tweaking to the workings of the OverrideHELP option due to changes
    in _help() and supported()
  - Updated POD for supported() to describe changes to functionality
- Add buildreqs for Perl core modules that might be dual-lived

* Mon Jan  2 2012 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20
  - Fixed CPAN RT#73115 where it looks like the response() had unexpected
    breaks in it. Instead of returning "xyz message", the FTPS server was
    returning "x" on one line and "yz message" on another line, and the code
    was treating "x" as the entire response (since there was no "-" after it).
    Fixed so that if a response starts with a number that's less than 3 digits
    with nothing else following it, to assume we hit this bug. The risk to
    this fix is that we might try to read past the response on some other
    server and cause things to hang. So that's an issue to keep an eye out on
    after this release.
  - Fixed minor issue with "HELP" not supported on some boxes. If this happens,
    supported() will now always return false unless you use OverrideHELP.
  - Now prints the hash values chosen for new() to the logs.
  - Fixed so scrubbing out sensitive info from the logs is only done when debug
    is turned on instead of doing it all the time.
  - Reorganized the options to new() in the POD to put the less useful and
    special case options to new() last.
  - Other minor POD corrections and additions.

* Thu Oct 20 2011 Paul Howarth <paul@city-fan.org> - 0.19-1
- Update to 0.19
  - If you use SSL_Advanced, it now writes to STDERR that you are using a
    deprecated feature
  - Modified 10-complex.t and 20-certificate.t to honor the PERL_MM_USE_DEFAULT
    environment variable for the smoke testers to always use defaults, which
    skips executing these 2 scripts (CPAN RT#69982)
  - Fixed typos in POD text and some misleading comments (CPAN RT#70438)
  - Updated the README file to include comments on t/20-certificate.t and what
    changes are required before you can use it
  - Updated t/20-certificate.t to highlight the section of code that the README
    file is talking about and the initial prompt to remind the user to see the
    the README file for the needed modifications before running the test!
- BR: perl(Carp)

* Wed Aug  3 2011 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18
  - More fixes/clarifications to the POD text
  - Fixed minor wild card issue with LIST & NLST if "+" was in the file name
  - Added LocalAddr option to new(); works against both the command channel
    and the data channel
  - Added restart() function to be compatible with Net::FTP for restarts
  - Added ability to restart downloads/get() where previous attempt left off
  - Added ability to restart uploads/put() where previous attempt left off
  - Added append() command [APPE]; it also uses OFFSET, but doesn't send the
    REST command to the server
  - Masks out the user name used when generating a log file, similar to how
    this is already done for the password except that it must also hide it in
    the response to USER & PASS; it's only masked when written to the log -
    message() and last_message() still return the user name unmasked in any
    response string!
  - Fixed a bug in t/10-complex.t and added optional environment variables
    for some of the connection values to make it easier for to quickly re-run
    tests during development without having to key in answers to questions
    with no good default values over and over again
  - Added SSL_Client_Certificate to support client certificates on the data
    channel as well as the command channel (CPAN RT#69327)
  - Deprecated SSL_Advanced in favor of SSL_Client_Certificate; SSL_Advanced is
    now just an alias for SSL_Client_Certificate for backwards compatibility;
    the new name better describes what we are trying to do with it now that
    this feature is supported
  - Wrote t/20-certificate.t to test this out, though this and t/10-complex.t
    are probably incompatible in most settings - anyone else trying to use this
    test case will have to modify the code to point to their certificate and
    provide its password, since the upstream test client certificate isn't
    going to be published
  - Calls to command() now return a reference to this class so that you can
    code something like: "if ($ftps->command("NOOP")->response() == CMD_OK)"
  - Modifed Net::FTPSSL to use the new command()->response() format internally

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 0.17-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jan  4 2011 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17
  - Fixed a subtle bug in response(), which now tests if parse succeeded
    instead of assuming it
  - Reordered the methods in the POD
  - Reworked t/10-complex.t quite a bit
  - Fixed the smoke tester failures (CPAN RT#64109)
  - t/10-complex.t now checks if OverridePASV or OverrideHELP are needed against
    the test server and dynamically adds it for the test cases if needed
  - Added PASV/EPSV prompt to t/10-complex.t script instead of assuming PASV
- Drop patch for CPAN RT#64109, now fixed upstream

* Wed Dec 22 2010 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16 (see Changes for details)
- Fix incorrect skip count in t/10-complex.t (CPAN RT#64109)

* Wed Dec 22 2010 Paul Howarth <paul@city-fan.org> - 0.15-3
- Import from Fedora

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.15-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Fri Jul 02 2010 Lubomir Rintel (Good Data) <lubo.rintel@gooddata.com> 0.15-1
- Specfile autogenerated by cpanspec 1.78
- Add missing BR, fix up some strings
